/***********************************************************************/
/*                                                                     */
/*   Procedure: LISTDATE                                               */
/*   Purpose:   Find all date items in the active database and save    */
/*              the item names to a file.                              */
/*   Output:    <dbname> LISTDATE A.                                   */
/*       Column  1 - 16: ITEM NAME                                     */
/*              19 - 34: DISPLAY TYPE                                  */
/*              37 - 44: ITEM TYPE                                     */
/*              47 - 62: SEGMENT NAME                                  */
/*              65 - 80: MASTER NAME                                   */
/***********************************************************************/
/*   Author:       KUEN-YIH CHANG (SIU-SOM)                            */
/*   Date:         June 28 1996                                        */
/*                                                                     */
/***********************************************************************/
 
ON FATAL DO;
   PRINT (&ERROR) NO INDEX;
   PRINT 'PROCESS ABORT.';
   EXIT;
END;
 
PROC (&DB_NAME);                       /* Database to reorganize */
IF &DB_NAME = &NAV THEN DO;
   IF &&DBNAME = &NAV THEN DO;
      PRINT 'NO DATABASE SPECIFIED NOR ACTIVATED, PROCESS ABORT.';
      EXIT;
   END;
   ELSE DO;
      &DB_NAME = &&DBNAME;
      PRINT 'NO DATABASE SPECIFIED, USE ACTIVE DATABASE: ' CAT &DB_NAME;
   END;
END;
ELSE IF &DB_NAME NE &DBNAME THEN DO;
   TRANS;
   DA ?(&DB_NAME) otw;
   UNTRANS;
END;
&DB_NAME = &&DBNAME;
 
declare &masters(0) as a16;
declare &master_name as a18;
declare &master_cnt as 9999;
declare &loop_cnt as 9999;
 
TRANS;
 
/* build array of master and index names */
SLIST FILE;
&masters = instance(slist.segment where slist.segment ne ' ');
&masters = &masters(findex(freq(&masters) ne &nav,all));
&masters = fill(&masters,elim);
 
&master_cnt = count(&masters);
 
/* For each element in &masters determine what database it comes from  */
/* (result stored in &dbofmaster) and what type of object it is (result*/
/* stored in &typeofmaster).  If the master is a type 'MASTER' and it  */
/* is from a different database than the requested database, a DBCLEAR */
/* MASTERS is performed on the master.                                 */
 
for &loop_cnt = 1 to &master_cnt
do;
   &master_name = '' cat &masters(&loop_cnt) cat '';
   &dbofmaster = ddquery('FILENAME', '?(&master_name)') ;
   &typeofmaster = ddquery('TYPE', '?(&master_name)') ;
   if (&dbofmaster ne &db_name) and (&typeofmaster eq 'MASTER')
   then do;
      dbclear masters ?(&master_name);
      pri 'DBCLEAR for master name: ' (&master_name)
                     ' in database: ' (&dbofmaster);
   end;
end;
 
SLIST FILE;
&masters = instance(slist.segment where slist.segment ne ' ');
&masters = &masters(findex(freq(&masters) ne &nav,all));
&masters = fill(&masters,elim);
 
&master_cnt = count(&masters);
 
&INDENT = -1;
FILE DEFINE OUTFILE &DB_NAME LISTDATE A LENGTH 80 F CREATE;
 
FROM SLIST LIST NAME DISPLAY TYPE SEGMENT MASTER
WHERE SLIST.DISPLAY CONTAINS('DATE')
NOHEAD NOEJECT BOTH
ON OUTFILE
OTW
PRINT 'No date item found in ' cat &db_name catb '.';
IFOK
PRINT 'All date items are output to file ' cat &db_name catb ' LISTDATE A';
FILE CLEAR OUTFILE;
CLEAR SYSTEM;
UNTRANS;
 

